/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'zh-cn', {
	button: {
		title: '按钮属性',
		text: '标签(值)',
		type: '类型',
		typeBtn: '按钮',
		typeSbm: '提交',
		typeRst: '重设'
	},
	checkboxAndRadio: {
		checkboxTitle: '复选框属性',
		radioTitle: '单选按钮属性',
		value: '选定值',
		selected: '已勾选',
		required: '必选'
	},
	form: {
		title: '表单属性',
		menu: '表单属性',
		action: '动作',
		method: '方法',
		encoding: '表单编码'
	},
	hidden: {
		title: '隐藏域属性',
		name: '名称',
		value: '初始值'
	},
	select: {
		title: '菜单/列表属性',
		selectInfo: '选择信息',
		opAvail: '可选项',
		value: '值',
		size: '高度',
		lines: '行',
		chkMulti: '允许多选',
		required: '必选',
		opText: '选项文本',
		opValue: '选项值',
		btnAdd: '添加',
		btnModify: '修改',
		btnUp: '上移',
		btnDown: '下移',
		btnSetValue: '设为初始选定',
		btnDelete: '删除'
	},
	textarea: {
		title: '多行文本属性',
		cols: '字符宽度',
		rows: '行数'
	},
	textfield: {
		title: '单行文本属性',
		name: '名称',
		value: '初始值',
		charWidth: '字符宽度',
		maxChars: '最多字符数',
		required: '必填',
		type: '类型',
		typeText: '文本',
		typePass: '密码',
		typeEmail: 'Email',
		typeSearch: '搜索',
		typeTel: '电话号码',
		typeUrl: '地址'
	}
} );
